package Monitoring::GLPlugin::SNMP::MibsAndOids::WEBGRAPHTHERMOHYGROBAROMETERUSMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'WebGraph-Thermo-Hygro-Barometer-US-MIB'} = {
  url => '',
  name => 'WebGraph-Thermo-Hygro-Barometer-US-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'WebGraph-Thermo-Hygro-Barometer-US-MIB'} =
    '1.3.6.1.4.1.5040.1.2.37';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-Thermo-Hygro-Barometer-US-MIB'} = {
  wut => '1.3.6.1.4.1.5040',
  wtComServer => '1.3.6.1.4.1.5040.1',
  wtWebio => '1.3.6.1.4.1.5040.1.2',
  wtWebGraphThermoBaro => '1.3.6.1.4.1.5040.1.2.37',
  wtWebGraphThermoBaroTemp => '1.3.6.1.4.1.5040.1.2.37.1',
  wtWebGraphThermoBaroSensors => '1.3.6.1.4.1.5040.1.2.37.1.1',
  wtWebGraphThermoBaroSensorTable => '1.3.6.1.4.1.5040.1.2.37.1.2',
  wtWebGraphThermoBaroSensorEntry => '1.3.6.1.4.1.5040.1.2.37.1.2.1',
  wtWebGraphThermoBaroSensorNo => '1.3.6.1.4.1.5040.1.2.37.1.2.1.1',
  wtWebGraphThermoBaroTempValueTable => '1.3.6.1.4.1.5040.1.2.37.1.3',
  wtWebGraphThermoBaroTempValueEntry => '1.3.6.1.4.1.5040.1.2.37.1.3.1',
  wtWebGraphThermoBaroTempValue => '1.3.6.1.4.1.5040.1.2.37.1.3.1.1',
  wtWebGraphThermoBaroBinaryTempValueTable => '1.3.6.1.4.1.5040.1.2.37.1.4',
  wtWebGraphThermoBaroBinaryTempValueEntry => '1.3.6.1.4.1.5040.1.2.37.1.4.1',
  wtWebGraphThermoBaroBinaryTempValue => '1.3.6.1.4.1.5040.1.2.37.1.4.1.1',
  wtWebGraphThermoBaroTempValuePktTable => '1.3.6.1.4.1.5040.1.2.37.1.8',
  wtWebGraphThermoBaroTempValuePktEntry => '1.3.6.1.4.1.5040.1.2.37.1.8.1',
  wtWebGraphThermoBaroTempValuePkt => '1.3.6.1.4.1.5040.1.2.37.1.8.1.1',
  wtWebGraphThermoBaroSessCntrl => '1.3.6.1.4.1.5040.1.2.37.2',
  wtWebGraphThermoBaroSessCntrlPassword => '1.3.6.1.4.1.5040.1.2.37.2.1',
  wtWebGraphThermoBaroSessCntrlConfigMode => '1.3.6.1.4.1.5040.1.2.37.2.2',
  wtWebGraphThermoBaroSessCntrlConfigModeDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroSessCntrlConfigMode',
  wtWebGraphThermoBaroSessCntrlLogout => '1.3.6.1.4.1.5040.1.2.37.2.3',
  wtWebGraphThermoBaroSessCntrlAdminPassword => '1.3.6.1.4.1.5040.1.2.37.2.4',
  wtWebGraphThermoBaroSessCntrlConfigPassword => '1.3.6.1.4.1.5040.1.2.37.2.5',
  wtWebGraphThermoBaroConfig => '1.3.6.1.4.1.5040.1.2.37.3',
  wtWebGraphThermoBaroDevice => '1.3.6.1.4.1.5040.1.2.37.3.1',
  wtWebGraphThermoBaroText => '1.3.6.1.4.1.5040.1.2.37.3.1.1',
  wtWebGraphThermoBaroDeviceName => '1.3.6.1.4.1.5040.1.2.37.3.1.1.1',
  wtWebGraphThermoBaroDeviceText => '1.3.6.1.4.1.5040.1.2.37.3.1.1.2',
  wtWebGraphThermoBaroDeviceLocation => '1.3.6.1.4.1.5040.1.2.37.3.1.1.3',
  wtWebGraphThermoBaroDeviceContact => '1.3.6.1.4.1.5040.1.2.37.3.1.1.4',
  wtWebGraphThermoBaroTimeDate => '1.3.6.1.4.1.5040.1.2.37.3.1.2',
  wtWebGraphThermoBaroTimeZone => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1',
  wtWebGraphThermoBaroTzOffsetHrs => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.1',
  wtWebGraphThermoBaroTzOffsetMin => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.2',
  wtWebGraphThermoBaroTzEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.3',
  wtWebGraphThermoBaroStTzOffsetHrs => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.4',
  wtWebGraphThermoBaroStTzOffsetMin => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.5',
  wtWebGraphThermoBaroStTzEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.6',
  wtWebGraphThermoBaroStTzStartMonth => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.7',
  wtWebGraphThermoBaroStTzStartMonthDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStartMonth',
  wtWebGraphThermoBaroStTzStartMode => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.8',
  wtWebGraphThermoBaroStTzStartModeDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStartMode',
  wtWebGraphThermoBaroStTzStartWday => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.9',
  wtWebGraphThermoBaroStTzStartWdayDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStartWday',
  wtWebGraphThermoBaroStTzStartHrs => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.10',
  wtWebGraphThermoBaroStTzStartMin => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.11',
  wtWebGraphThermoBaroStTzStopMonth => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.12',
  wtWebGraphThermoBaroStTzStopMonthDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStopMonth',
  wtWebGraphThermoBaroStTzStopMode => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.13',
  wtWebGraphThermoBaroStTzStopModeDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStopMode',
  wtWebGraphThermoBaroStTzStopWday => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.14',
  wtWebGraphThermoBaroStTzStopWdayDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroStTzStopWday',
  wtWebGraphThermoBaroStTzStopHrs => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.15',
  wtWebGraphThermoBaroStTzStopMin => '1.3.6.1.4.1.5040.1.2.37.3.1.2.1.16',
  wtWebGraphThermoBaroTimeServer => '1.3.6.1.4.1.5040.1.2.37.3.1.2.2',
  wtWebGraphThermoBaroTimeServer1 => '1.3.6.1.4.1.5040.1.2.37.3.1.2.2.1',
  wtWebGraphThermoBaroTimeServer2 => '1.3.6.1.4.1.5040.1.2.37.3.1.2.2.2',
  wtWebGraphThermoBaroTsEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.2.2.3',
  wtWebGraphThermoBaroTsSyncTime => '1.3.6.1.4.1.5040.1.2.37.3.1.2.2.4',
  wtWebGraphThermoBaroDeviceClock => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3',
  wtWebGraphThermoBaroClockHrs => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3.1',
  wtWebGraphThermoBaroClockMin => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3.2',
  wtWebGraphThermoBaroClockDay => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3.3',
  wtWebGraphThermoBaroClockMonth => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3.4',
  wtWebGraphThermoBaroClockMonthDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroClockMonth',
  wtWebGraphThermoBaroClockYear => '1.3.6.1.4.1.5040.1.2.37.3.1.2.3.5',
  wtWebGraphThermoBaroBasic => '1.3.6.1.4.1.5040.1.2.37.3.1.3',
  wtWebGraphThermoBaroNetwork => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1',
  wtWebGraphThermoBaroIpAddress => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.1',
  wtWebGraphThermoBaroSubnetMask => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.2',
  wtWebGraphThermoBaroGateway => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.3',
  wtWebGraphThermoBaroDnsServer1 => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.4',
  wtWebGraphThermoBaroDnsServer2 => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.5',
  wtWebGraphThermoBaroAddConfig => '1.3.6.1.4.1.5040.1.2.37.3.1.3.1.6',
  wtWebGraphThermoBaroHTTP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.2',
  wtWebGraphThermoBaroStartup => '1.3.6.1.4.1.5040.1.2.37.3.1.3.2.1',
  wtWebGraphThermoBaroGetHeaderEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.2.2',
  wtWebGraphThermoBaroHttpPort => '1.3.6.1.4.1.5040.1.2.37.3.1.3.2.3',
  wtWebGraphThermoBaroMail => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3',
  wtWebGraphThermoBaroMailAdName => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.1',
  wtWebGraphThermoBaroMailReply => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.2',
  wtWebGraphThermoBaroMailServer => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.3',
  wtWebioAn1MailEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.4',
  wtWebGraphThermoBaroMailAuthentication => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.5',
  wtWebGraphThermoBaroMailAuthUser => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.6',
  wtWebGraphThermoBaroMailAuthPassword => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.7',
  wtWebGraphThermoBaroMailPop3Server => '1.3.6.1.4.1.5040.1.2.37.3.1.3.3.8',
  wtWebGraphThermoBaroSNMP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4',
  wtWebGraphThermoBaroSnmpCommunityStringRead => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.1',
  wtWebGraphThermoBaroSnmpCommunityStringReadWrite => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.2',
  wtWebGraphThermoBaroSystemTrapManagerIP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.3',
  wtWebGraphThermoBaroSystemTrapEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.4',
  wtWebGraphThermoBaroSnmpEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.5',
  wtWebGraphThermoBaroSnmpCommunityStringTrap => '1.3.6.1.4.1.5040.1.2.37.3.1.3.4.6',
  wtWebGraphThermoBaroUDP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.5',
  wtWebGraphThermoBaroUdpPort => '1.3.6.1.4.1.5040.1.2.37.3.1.3.5.1',
  wtWebGraphThermoBaroUdpEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.5.2',
  wtWebGraphThermoBaroSyslog => '1.3.6.1.4.1.5040.1.2.37.3.1.3.6',
  wtWebGraphThermoBaroSyslogServerIP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.6.1',
  wtWebGraphThermoBaroSyslogServerPort => '1.3.6.1.4.1.5040.1.2.37.3.1.3.6.2',
  wtWebGraphThermoBaroSyslogSystemMessagesEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.6.3',
  wtWebGraphThermoBaroSyslogEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.6.4',
  wtWebGraphThermoBaroFTP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7',
  wtWebGraphThermoBaroFTPServerIP => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.1',
  wtWebGraphThermoBaroFTPServerControlPort => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.2',
  wtWebGraphThermoBaroFTPUserName => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.3',
  wtWebGraphThermoBaroFTPPassword => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.4',
  wtWebGraphThermoBaroFTPAccount => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.5',
  wtWebGraphThermoBaroFTPOption => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.6',
  wtWebGraphThermoBaroFTPEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.3.7.7',
  wtWebGraphThermoBaroRSS => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8',
  wtWebGraphThermoBaroRSSChannelTitle => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.1',
  wtWebGraphThermoBaroRSSChannelLink => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.2',
  wtWebGraphThermoBaroRSSChannelDescription => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.3',
  wtWebGraphThermoBaroRSSChannelImage => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.4',
  wtWebGraphThermoBaroRSSChannelImageTitle => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.5',
  wtWebGraphThermoBaroRSSChannelImageLink => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.6',
  wtWebGraphThermoBaroRSSChannelItemTitle => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.7',
  wtWebGraphThermoBaroRSSChannelItemLink => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.8',
  wtWebGraphThermoBaroRSSChannelItemDescription => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.9',
  wtWebGraphThermoBaroRSSChannelItemQuantity => '1.3.6.1.4.1.5040.1.2.37.3.1.3.8.10',
  wtWebGraphThermoBaroLanguage => '1.3.6.1.4.1.5040.1.2.37.3.1.3.9',
  wtWebGraphThermoBaroLanguageSelect => '1.3.6.1.4.1.5040.1.2.37.3.1.3.9.1',
  wtWebGraphThermoBaroDatalogger => '1.3.6.1.4.1.5040.1.2.37.3.1.4',
  wtWebGraphThermoBaroLoggerTimebase => '1.3.6.1.4.1.5040.1.2.37.3.1.4.1',
  wtWebGraphThermoBaroLoggerTimebaseDefinition => 'WebGraph-Thermo-Hygro-Barometer-US-MIB::wtWebGraphThermoBaroLoggerTimebase',
  wtWebGraphThermoBaroLoggerSensorSel => '1.3.6.1.4.1.5040.1.2.37.3.1.4.2',
  wtWebGraphThermoBaroAlarm => '1.3.6.1.4.1.5040.1.2.37.3.1.5',
  wtWebGraphThermoBaroAlarmCount => '1.3.6.1.4.1.5040.1.2.37.3.1.5.1',
  wtWebGraphThermoBaroAlarmIfTable => '1.3.6.1.4.1.5040.1.2.37.3.1.5.2',
  wtWebGraphThermoBaroAlarmIfEntry => '1.3.6.1.4.1.5040.1.2.37.3.1.5.2.1',
  wtWebGraphThermoBaroAlarmNo => '1.3.6.1.4.1.5040.1.2.37.3.1.5.2.1.1',
  wtWebGraphThermoBaroAlarmTable => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3',
  wtWebGraphThermoBaroAlarmEntry => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1',
  wtWebGraphThermoBaroAlarmTrigger => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.1',
  wtWebGraphThermoBaroAlarmMin => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.2',
  wtWebGraphThermoBaroAlarmMax => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.3',
  wtWebGraphThermoBaroAlarmHysteresis => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.4',
  wtWebGraphThermoBaroAlarmDelay => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.5',
  wtWebGraphThermoBaroAlarmInterval => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.6',
  wtWebGraphThermoBaroAlarmEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.7',
  wtWebGraphThermoBaroAlarmEMailAddr => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.8',
  wtWebGraphThermoBaroAlarmMailSubject => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.9',
  wtWebGraphThermoBaroAlarmMailText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.10',
  wtWebGraphThermoBaroAlarmManagerIP => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.11',
  wtWebGraphThermoBaroAlarmTrapText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.12',
  wtWebGraphThermoBaroAlarmMailOptions => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.13',
  wtWebGraphThermoBaroAlarmTcpIpAddr => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.14',
  wtWebGraphThermoBaroAlarmTcpPort => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.15',
  wtWebGraphThermoBaroAlarmTcpText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.16',
  wtWebGraphThermoBaroAlarmClearMailSubject => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.17',
  wtWebGraphThermoBaroAlarmClearMailText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.18',
  wtWebGraphThermoBaroAlarmClearTrapText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.19',
  wtWebGraphThermoBaroAlarmClearTcpText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.20',
  wtWebGraphThermoBaroAlarmDeltaTemp => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.21',
  wtWebGraphThermoBaroAlarmRHMin => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.22',
  wtWebGraphThermoBaroAlarmRHMax => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.23',
  wtWebGraphThermoBaroAlarmRHHysteresis => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.24',
  wtWebGraphThermoBaroAlarmAHMin => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.25',
  wtWebGraphThermoBaroAlarmAHMax => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.26',
  wtWebGraphThermoBaroAlarmSyslogIpAddr => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.27',
  wtWebGraphThermoBaroAlarmSyslogPort => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.28',
  wtWebGraphThermoBaroAlarmSyslogText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.29',
  wtWebGraphThermoBaroAlarmSyslogClearText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.30',
  wtWebGraphThermoBaroAlarmFtpDataPort => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.31',
  wtWebGraphThermoBaroAlarmFtpFileName => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.32',
  wtWebGraphThermoBaroAlarmFtpText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.33',
  wtWebGraphThermoBaroAlarmFtpClearText => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.34',
  wtWebGraphThermoBaroAlarmFtpOption => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.35',
  wtWebGraphThermoBaroAlarmTimerCron => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.36',
  wtWebGraphThermoBaroAlarmName => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.39',
  wtWebGraphThermoBaroAlarmActive => '1.3.6.1.4.1.5040.1.2.37.3.1.5.3.1.40',
  wtWebGraphThermoBaroGraphics => '1.3.6.1.4.1.5040.1.2.37.3.1.6',
  wtWebGraphThermoBaroGraphicsBase => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1',
  wtWebGraphThermoBaroGraphicsBaseEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.1',
  wtWebGraphThermoBaroGraphicsBaseWidth => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.2',
  wtWebGraphThermoBaroGraphicsBaseHeight => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.3',
  wtWebGraphThermoBaroGraphicsBaseFrameColor => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.4',
  wtWebGraphThermoBaroGraphicsBaseBackgroundColor => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.5',
  wtWebGraphThermoBaroGraphicsBasePollingrate => '1.3.6.1.4.1.5040.1.2.37.3.1.6.1.6',
  wtWebGraphThermoBaroGraphicsSelect => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2',
  wtWebGraphThermoBaroGraphicsSelectDisplaySensorSel => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.1',
  wtWebGraphThermoBaroGraphicsSelectDisplayShowExtrem => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.2',
  wtWebGraphThermoBaroSensorColorTable => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.3',
  wtWebGraphThermoBaroSensorColorEntry => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.3.1',
  wtWebGraphThermoBaroGraphicsSensorColor => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.3.1.1',
  wtWebGraphThermoBaroGraphicsSelectScale => '1.3.6.1.4.1.5040.1.2.37.3.1.6.2.3.1.2',
  wtWebGraphThermoBaroGraphicsScale => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3',
  wtWebGraphThermoBaroGraphicsScaleAutoScaleEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.1',
  wtWebGraphThermoBaroGraphicsScaleAutoFitEnable => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.2',
  wtWebGraphThermoBaroGraphicsScale1Min => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.3',
  wtWebGraphThermoBaroGraphicsScale2Min => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.4',
  wtWebGraphThermoBaroGraphicsScale3Min => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.5',
  wtWebGraphThermoBaroGraphicsScale4Min => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.6',
  wtWebGraphThermoBaroGraphicsScale1Max => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.7',
  wtWebGraphThermoBaroGraphicsScale2Max => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.8',
  wtWebGraphThermoBaroGraphicsScale3Max => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.9',
  wtWebGraphThermoBaroGraphicsScale4Max => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.10',
  wtWebGraphThermoBaroGraphicsScale1Unit => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.11',
  wtWebGraphThermoBaroGraphicsScale2Unit => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.12',
  wtWebGraphThermoBaroGraphicsScale3Unit => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.13',
  wtWebGraphThermoBaroGraphicsScale4Unit => '1.3.6.1.4.1.5040.1.2.37.3.1.6.3.14',
  wtWebGraphThermoBaroPorts => '1.3.6.1.4.1.5040.1.2.37.3.2',
  wtWebGraphThermoBaroPortTable => '1.3.6.1.4.1.5040.1.2.37.3.2.1',
  wtWebGraphThermoBaroPortEntry => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1',
  wtWebGraphThermoBaroPortName => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.1',
  wtWebGraphThermoBaroPortText => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.2',
  wtWebGraphThermoBaroPortOffset1 => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.3',
  wtWebGraphThermoBaroPortTemperature1 => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.4',
  wtWebGraphThermoBaroPortOffset2 => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.5',
  wtWebGraphThermoBaroPortTemperature2 => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.6',
  wtWebGraphThermoBaroPortComment => '1.3.6.1.4.1.5040.1.2.37.3.2.1.1.7',
  wtWebGraphThermoBaroPortAltidude => '1.3.6.1.4.1.5040.1.2.37.3.2.2',
  wtWebGraphThermoBaroManufact => '1.3.6.1.4.1.5040.1.2.37.3.3',
  wtWebGraphThermoBaroMfName => '1.3.6.1.4.1.5040.1.2.37.3.3.1',
  wtWebGraphThermoBaroMfAddr => '1.3.6.1.4.1.5040.1.2.37.3.3.2',
  wtWebGraphThermoBaroMfHotline => '1.3.6.1.4.1.5040.1.2.37.3.3.3',
  wtWebGraphThermoBaroMfInternet => '1.3.6.1.4.1.5040.1.2.37.3.3.4',
  wtWebGraphThermoBaroMfDeviceTyp => '1.3.6.1.4.1.5040.1.2.37.3.3.5',
  wtWebGraphThermoBaroMfOrderNo => '1.3.6.1.4.1.5040.1.2.37.3.3.6',
  wtWebGraphThermoBaroDiag => '1.3.6.1.4.1.5040.1.2.37.4',
  wtWebGraphThermoBaroDiagErrorCount => '1.3.6.1.4.1.5040.1.2.37.4.1',
  wtWebGraphThermoBaroDiagBinaryError => '1.3.6.1.4.1.5040.1.2.37.4.2',
  wtWebGraphThermoBaroDiagErrorIndex => '1.3.6.1.4.1.5040.1.2.37.4.3',
  wtWebGraphThermoBaroDiagErrorMessage => '1.3.6.1.4.1.5040.1.2.37.4.4',
  wtWebGraphThermoBaroDiagErrorClear => '1.3.6.1.4.1.5040.1.2.37.4.5',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'WebGraph-Thermo-Hygro-Barometer-US-MIB'} = {
  wtWebGraphThermoBaroLoggerTimebase => {
    '1' => 'wtWebGraphThermoBaroDatalogger-1Min',
    '2' => 'wtWebGraphThermoBaroDatalogger-5Min',
    '3' => 'wtWebGraphThermoBaroDatalogger-15Min',
    '4' => 'wtWebGraphThermoBaroDatalogger-60Min',
  },
  wtWebGraphThermoBaroStTzStopWday => {
    '1' => 'wtWebGraphThermoBaroStopWday-Sunday',
    '2' => 'wtWebGraphThermoBaroStopWday-Monday',
    '3' => 'wtWebGraphThermoBaroStopWday-Tuesday',
    '4' => 'wtWebGraphThermoBaroStopWday-Thursday',
    '5' => 'wtWebGraphThermoBaroStopWday-Wednesday',
    '6' => 'wtWebGraphThermoBaroStopWday-Friday',
    '7' => 'wtWebGraphThermoBaroStopWday-Saturday',
  },
  wtWebGraphThermoBaroSessCntrlConfigMode => {
    '0' => 'wtWebGraphThermoBaroSessCntrl-NoSession',
    '1' => 'wtWebGraphThermoBaroSessCntrl-Session',
  },
  wtWebGraphThermoBaroStTzStartMode => {
    '1' => 'wtWebGraphThermoBaroStartMode-first',
    '2' => 'wtWebGraphThermoBaroStartMode-second',
    '3' => 'wtWebGraphThermoBaroStartMode-third',
    '4' => 'wtWebGraphThermoBaroStartMode-fourth',
    '5' => 'wtWebGraphThermoBaroStartMode-last',
  },
  wtWebGraphThermoBaroClockMonth => {
    '1' => 'wtWebGraphThermoBaroClockMonth-January',
    '2' => 'wtWebGraphThermoBaroClockMonth-February',
    '3' => 'wtWebGraphThermoBaroClockMonth-March',
    '4' => 'wtWebGraphThermoBaroClockMonth-April',
    '5' => 'wtWebGraphThermoBaroClockMonth-May',
    '6' => 'wtWebGraphThermoBaroClockMonth-June',
    '7' => 'wtWebGraphThermoBaroClockMonth-July',
    '8' => 'wtWebGraphThermoBaroClockMonth-August',
    '9' => 'wtWebGraphThermoBaroClockMonth-September',
    '10' => 'wtWebGraphThermoBaroClockMonth-October',
    '11' => 'wtWebGraphThermoBaroClockMonth-November',
    '12' => 'wtWebGraphThermoBaroClockMonth-December',
  },
  wtWebGraphThermoBaroStTzStartMonth => {
    '1' => 'wtWebGraphThermoBaroStartMonth-January',
    '2' => 'wtWebGraphThermoBaroStartMonth-February',
    '3' => 'wtWebGraphThermoBaroStartMonth-March',
    '4' => 'wtWebGraphThermoBaroStartMonth-April',
    '5' => 'wtWebGraphThermoBaroStartMonth-May',
    '6' => 'wtWebGraphThermoBaroStartMonth-June',
    '7' => 'wtWebGraphThermoBaroStartMonth-July',
    '8' => 'wtWebGraphThermoBaroStartMonth-August',
    '9' => 'wtWebGraphThermoBaroStartMonth-September',
    '10' => 'wtWebGraphThermoBaroStartMonth-October',
    '11' => 'wtWebGraphThermoBaroStartMonth-November',
    '12' => 'wtWebGraphThermoBaroStartMonth-December',
  },
  wtWebGraphThermoBaroStTzStopMonth => {
    '1' => 'wtWebGraphThermoBaroStopMonth-January',
    '2' => 'wtWebGraphThermoBaroStopMonth-February',
    '3' => 'wtWebGraphThermoBaroStopMonth-March',
    '4' => 'wtWebGraphThermoBaroStopMonth-April',
    '5' => 'wtWebGraphThermoBaroStopMonth-May',
    '6' => 'wtWebGraphThermoBaroStopMonth-June',
    '7' => 'wtWebGraphThermoBaroStopMonth-July',
    '8' => 'wtWebGraphThermoBaroStopMonth-August',
    '9' => 'wtWebGraphThermoBaroStopMonth-September',
    '10' => 'wtWebGraphThermoBaroStopMonth-October',
    '11' => 'wtWebGraphThermoBaroStopMonth-November',
    '12' => 'wtWebGraphThermoBaroStopMonth-December',
  },
  wtWebGraphThermoBaroStTzStartWday => {
    '1' => 'wtWebGraphThermoBaroStartWday-Sunday',
    '2' => 'wtWebGraphThermoBaroStartWday-Monday',
    '3' => 'wtWebGraphThermoBaroStartWday-Tuesday',
    '4' => 'wtWebGraphThermoBaroStartWday-Thursday',
    '5' => 'wtWebGraphThermoBaroStartWday-Wednesday',
    '6' => 'wtWebGraphThermoBaroStartWday-Friday',
    '7' => 'wtWebGraphThermoBaroStartWday-Saturday',
  },
  wtWebGraphThermoBaroStTzStopMode => {
    '1' => 'wtWebGraphThermoBaroStopMode-first',
    '2' => 'wtWebGraphThermoBaroStopMode-second',
    '3' => 'wtWebGraphThermoBaroStopMode-third',
    '4' => 'wtWebGraphThermoBaroStopMode-fourth',
    '5' => 'wtWebGraphThermoBaroStopMode-last',
  },
};
